#include "RemoteUserItem.h"
#include "RemoteFileItem.h"
#include "ShareWindow.h"

RemoteUserItem ::
RemoteUserItem(ShareWindow * owner, const char * sessionID)
   : _owner(owner), _sessionID(sessionID), _handle("Anonymous"), _files(CStringHashFunc), _port(0), _firewalled(false), _bandwidthLabel("Unknown"), _bandwidth(0)
{
   _files.SetCompareFunction(CStringCompareFunc);
 
   PortableString text = GetUserString();
   text += " is now connected.";
   _owner->LogMessage(LOG_INFORMATION_MESSAGE, text.Cstr());

   SetColumnContent(0, _handle.Cstr());
   SetColumnContent(1, _sessionID.Cstr());
}

RemoteUserItem ::
~RemoteUserItem()
{
   PortableString text = GetUserString();
   text += " has disconnected.";
   _owner->LogMessage(LOG_INFORMATION_MESSAGE, text.Cstr());
   ClearFiles();
}

PortableString
RemoteUserItem ::
GetUserString() const
{
   PortableString text("User #");
   text += _sessionID;

   if (!_handle.Equals("Anonymous"))
   {
      text += " (a.k.a. ";
      text += _handle.Cstr();
      text += ")";
   }
   return text;
}

void
RemoteUserItem ::
SetHandle(const char * handle)
{
   PortableString text = GetUserString();
   text += " is now known as ";
   text += handle;
   _owner->LogMessage(LOG_INFORMATION_MESSAGE, text.Cstr());

   _handle = handle;
   SetColumnContent(0, _handle.Cstr());
   _owner->RefreshUserItem(this);

   // Make sure all our files refresh too, in case the "owner name" column is visible
   RemoteFileItem * next;
   PortableHashtableIterator<const char *, RemoteFileItem *> iter = _files.GetIterator();
   while(iter.GetNextValue(next)) _owner->RefreshFileItem(next);
}

void
RemoteUserItem ::
SetBandwidth(const char * bandwidthLabel, uint32 bps)
{
   _bandwidthLabel = bandwidthLabel;
   _bandwidth = bps;

   // Make sure all our files refresh too, in case the "owner bps" column is visible
   RemoteFileItem * next;
   PortableHashtableIterator<const char *, RemoteFileItem *> iter = _files.GetIterator();
   while(iter.GetNextValue(next)) _owner->RefreshFileItem(next);
}

void
RemoteUserItem ::
ClearFiles()
{
   PortableHashtableIterator<const char *, RemoteFileItem *> iter = _files.GetIterator();
   RemoteFileItem * next;
   while(iter.GetNextValue(next)) 
   {
      _owner->RemoveFileItem(next);
      delete next;
   }
   _files.Clear();
}

void
RemoteUserItem ::
PutFile(const char * fileName, PortableMessageRef fileAttrs)
{
   RemoveFile(fileName);
   RemoteFileItem * item = new RemoteFileItem(this, fileName, fileAttrs);
   _files.Put(item->GetFileName(), item);
   _owner->AddFileItem(item);
}


void
RemoteUserItem ::
RemoveFile(const char * fileName)
{
   RemoteFileItem * item;
   if (_files.Remove(fileName, item))
   {
      _owner->RemoveFileItem(item);
      delete item;
   }
}

