#ifndef REMOTE_USER_H
#define REMOTE_USER_H

#include "message/PortableMessage.h"

#include "CLVEasyItem.h"

class RemoteFileItem;
class ShareWindow;
class BBitmap;

// This class represents a single remote user and his current matching file set
class RemoteUserItem : public CLVEasyItem
{
public:
   RemoteUserItem(ShareWindow * owner, const char * sessionID);

   ~RemoteUserItem();

   void SetHandle(const char * handle);
   void SetHostName(const char * hostName) {_hostName = hostName;}
   void SetPort(int port) {_port = port;}

   const char * GetFileCellText(const RemoteFileItem * file, int32 columnIndex) const;

   void PutFile(const char * fileName, PortableMessageRef fileAttrs);
   void RemoveFile(const char * fileName);
   void ClearFiles();

   int GetNumFiles() const {return _files.Size();}

   const char * GetSessionID() const {return _sessionID.Cstr();}
   const char * GetHandle() const {return _handle.Cstr();}
   const char * GetHostName() const {return _hostName.Cstr();}
   const char * GetBandwidthLabel() const {return _bandwidthLabel.Cstr();}
   uint32 GetBandwidth() const {return _bandwidth;}
   int GetPort() const {return _port;}

   ShareWindow * GetOwner() const {return _owner;}

   PortableString GetUserString() const;

   bool GetFirewalled() const {return _firewalled;}
   void SetFirewalled(bool f) {_firewalled = f;}

   void SetBandwidth(const char * label, uint32 bps);

private:
   ShareWindow * _owner;
   PortableString _sessionID;
   PortableString _handle;
   PortableString _hostName;
   int _port;
   bool _firewalled;

   PortableHashtable<const char *, RemoteFileItem *> _files;

   PortableString _bandwidthLabel;
   uint32 _bandwidth;
};


#endif
